@@ -53,6 +53,7 @@ from ploomber.io import pretty_print
 
 
 class IgnoreBlackWarning(logging.Filter):
+
     def filter(self, record):
         return 'Black is not installed' not in record.msg
 
@@ -148,6 +149,7 @@ def requires_path(func):
     Checks if NotebookSource instance was initialized from a file, raises
     an error if not
     """
+
     @wraps(func)
     def wrapper(self, *args, **kwargs):
 
@@ -179,11 +181,20 @@ class NotebookSource(Source):
     check_if_kernel_installed : bool, optional
         Check if the kernel is installed during initization
 
+    debug : bool, default=False
+        If True, adds a "%pbd on" cell at the beginning of the notebook.
+
     Notes
     -----
+    .. collapse:: changelog
+
+        .. versionchanged:: 0.19.9
+            ``debug`` flag.
+
     The render method prepares the notebook for execution: it adds the
     parameters and it makes sure kernelspec is defined
     """
+
     @requires([
         'parso', 'pyflakes', 'jupytext', 'nbformat', 'papermill',
         'jupyter_client'
@@ -194,7 +205,8 @@ class NotebookSource(Source):
                  ext_in=None,
                  kernelspec_name=None,
                  static_analysis='regular',
-                 check_if_kernel_installed=True):
+                 check_if_kernel_installed=True,
+                 debug=False):
         # any non-py file must first be converted using jupytext, we need
         # that representation for validation, if input is already a .py file
         # do not convert. If passed a string, try to guess format using
@@ -202,6 +214,7 @@ class NotebookSource(Source):
         # but do lazy loading in case we don't need both
         self._primitive = primitive
         self._check_if_kernel_installed = check_if_kernel_installed
+        self._debug = debug
 
         # this happens if using SourceLoader
         if isinstance(primitive, Placeholder):
@@ -333,6 +346,14 @@ class NotebookSource(Source):
         # will have an empty "papermill" metadata dictionary)
         nb = parameterize_notebook(nb, self._params)
 
+        # insert pdb cell, if needed
+        if self._debug:
+            source = ('# enable debugging (cell added by ploomber)\n'
+                      '%pdb on')
+            debugging_cell = nbformat.v4.new_code_cell(
+                source, metadata={'tags': ['debugging-settings']})
+            nb.cells.insert(0, debugging_cell)
+
         # delete empty tags to prevent cluttering the notebooks
         for cell in nb.cells:
             if not len(cell.metadata['tags']):
@@ -341,7 +362,7 @@ class NotebookSource(Source):
         self._nb_str_rendered = nbformat.writes(nb)
         self._post_render_validation()
 
-    def _read_nb_str_unrendered(self):
+    def _read_nb_str_unrendered(self, force=False):
         """
         Returns the notebook representation (JSON string), this is the raw
         source code passed, does not contain injected parameters.
@@ -352,10 +373,15 @@ class NotebookSource(Source):
         An exception is raised if we cannot determine kernel information.
         """
         # hot_reload causes to always re-evalaute the notebook representation
-        if self._nb_str_unrendered is None or self._hot_reload:
+        if self._nb_str_unrendered is None or self._hot_reload or force:
+            if force:
+                primitive = _read_primitive(self._path)
+            else:
+                primitive = self.primitive
+
             # this is the notebook node representation
             nb = _to_nb_obj(
-                self.primitive,
+                primitive,
                 ext=self._ext_in,
                 # passing the underscored version
                 # because that's the only one available
@@ -529,14 +555,15 @@ Go to: https://ploomber.io/s/params for more information
     def _nb_str_to_obj(self, nb_str):
         return nbformat.reads(nb_str, as_version=nbformat.NO_CONVERT)
 
-    def _get_parameters_cell(self):
-        self._read_nb_str_unrendered()
+    def _get_parameters_cell(self, force=False):
+        self._read_nb_str_unrendered(force=force)
         cell, _ = find_cell_with_tag(self._nb_obj_unrendered, tag='parameters')
         return cell.source
 
-    def extract_upstream(self):
+    def extract_upstream(self, force=False):
         extractor_class = extractor_class_for_language(self.language)
-        return extractor_class(self._get_parameters_cell()).extract_upstream()
+        return extractor_class(
+            self._get_parameters_cell(force=force)).extract_upstream()
 
     def extract_product(self):
         extractor_class = extractor_class_for_language(self.language)
