@@ -5,6 +5,7 @@ Note: All validation errors should raise DAGSpecInitializationError, this
 allows the CLI to signal that this is a user's input error and hides the
 traceback and only displays the error message
 """
+import mimetypes
 from functools import partial
 from copy import copy, deepcopy
 from pathlib import Path
@@ -41,12 +42,17 @@ def _safe_suffix(product):
 
 def _looks_like_path(s):
     system = platform.system()
+
     if system == 'Windows':
         return '\\' in s
     else:
         return '/' in s
 
 
+def _looks_like_file_name(s):
+    return mimetypes.guess_type(s)[0] is not None
+
+
 def _extension_typo(extension, valid_extensions):
     if extension and valid_extensions:
         return get_close_matches(extension, valid_extensions)
@@ -110,9 +116,17 @@ def task_class_from_source_str(source_str, lazy_import, reload, product):
             error = e
 
         if imported is None:
-            raise DAGSpecInitializationError(
-                'Failed to determine task class for '
-                f'source {source_str!r}: {error!s}. ')
+            if _looks_like_file_name(source_str):
+                raise DAGSpecInitializationError(
+                    'Failed to determine task class for '
+                    f'source {source_str!r} (invalid '
+                    f'extension {extension!r}). Valid extensions '
+                    f'are: {pretty_print.iterable(suffix2taskclass)}\n'
+                    'If you meant to import a function, please rename it.')
+            else:
+                raise DAGSpecInitializationError(
+                    'Failed to determine task class for '
+                    f'source {source_str!r}: {error!s}.')
         else:
             return tasks.PythonCallable
     else:
@@ -195,6 +209,7 @@ class TaskSpec(MutableMapping):
         if the module has already been imported. Has no effect if
         lazy_import=True.
     """
+
     def __init__(self,
                  data,
                  meta,
@@ -297,7 +312,7 @@ class TaskSpec(MutableMapping):
             product_class = _find_product_class(task_class, data, self.meta)
             product = data.pop('product')
             name = data.pop('name')
-            grid = data.pop('grid')
+            grid = _preprocess_grid_spec(data.pop('grid'))
 
             # hooks
             on_render = data.pop('on_render', None)
@@ -318,18 +333,25 @@ class TaskSpec(MutableMapping):
 
             params = data.pop('params', None)
 
+            # if the name argument is a placeholder, pass it in the namer
+            # argument to the placeholders are replaced by their values
+            if '[[' in name and ']]' in name:
+                name_arg = dict(namer=name)
+            else:
+                name_arg = dict(name=name)
+
             return TaskGroup.from_grid(task_class=task_class,
                                        product_class=product_class,
                                        product_primitive=product,
                                        task_kwargs=data,
                                        dag=dag,
-                                       name=name,
                                        grid=grid,
                                        resolve_relative_to=self.project_root,
                                        on_render=on_render,
                                        on_finish=on_finish,
                                        on_failure=on_failure,
-                                       params=params), upstream
+                                       params=params,
+                                       **name_arg), upstream
         else:
             return _init_task(data=data,
                               meta=self.meta,
@@ -594,3 +616,40 @@ def get_value_at(d, dotted_path):
             return None
 
     return current
+
+
+def _preprocess_grid_spec(grid_spec):
+    """
+    Preprocess a grid (list or dictionary) to expand values if it contains
+    dotted paths
+    """
+    if isinstance(grid_spec, Mapping):
+        return _preprocess_grid_spec_mapping(grid_spec)
+    else:
+        out = []
+
+        for element in grid_spec:
+            out.append(_preprocess_grid_spec_mapping(element))
+
+        return out
+
+
+def _preprocess_grid_spec_mapping(grid_spec):
+    """
+    Preprocess a grid (dictionary) to expand values if it contains
+    dotted paths
+    """
+    out = dict()
+
+    for key, value in grid_spec.items():
+        try:
+            dp = dotted_path.DottedPath(value, allow_return_none=False)
+        except TypeError:
+            dp = None
+
+        if dp:
+            out[key] = dp()
+        else:
+            out[key] = value
+
+    return out
